{% extends 'base.html' %}
{% load menu_tags %}

{% block content %}
	<div class="row">

		<div class="content-main">
			<h1>{{ self.title }}</h1>
			<p>Hello world.</p>

			<h4>Children Menu (max_levels=1)</h4>
			<div id="children-menu-one-level">
				{% children_menu %}
			</div>

			<h4>Children Menu (max_levels=3)</h4>
			<div id="children-menu-three-levels">
				{% children_menu max_levels=3 allow_repeating_parents=False %}
			</div>
		</div>

		<div class="content-secondary">
			<h4>Section Menu (show_multiple_levels=False)</h4>
			<div id="section-menu-one-level">
				{% section_menu show_multiple_levels=False %}
			</div>

			<h4>Section Menu (max_levels=2)</h4>
			<div id="section-menu-two-levels">
				{% section_menu max_levels=2 %}
			</div>

			<div id="sub-menu-no-page">
				{% sub_menu 'not-a-menuitem-or-page' %}
			</div>
		</div>

	</div>    
{% endblock %}
