{% extends 'base.html' %}
{% load menu_tags %}

{% block content %}
	
	<h1>{{ self.title }}</h1>
	<p>Hello world.</p>

	<h4>Children Menu (max_levels=1)</h4>
	<div id="children-menu-one-level">
		{% children_menu %}
	</div>

	<h4>Children Menu (max_levels=3)</h4>
	<div id="children-menu-three-levels">
		{% children_menu max_levels=3 allow_repeating_parents=False %}
	</div>

{% endblock %}
